[tor-commits] [tor/release-0.4.0] test/sr: update sr_state_free() to sr_state_free_all()

nickm at torproject.org nickm at torproject.org
Tue Mar 12 15:03:57 UTC 2019


commit dfc3e552a3b7617add0bd576a5c34dca59f42649
Author: teor <teor at torproject.org>
Date:   Tue Mar 12 11:34:52 2019 +1000

    test/sr: update sr_state_free() to sr_state_free_all()
    
    The function name changed between 0.2.9 and 0.3.4.
---
 src/test/test_shared_random.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/test/test_shared_random.c b/src/test/test_shared_random.c
index 45f0e1db7..991d73128 100644
--- a/src/test/test_shared_random.c
+++ b/src/test/test_shared_random.c
@@ -548,7 +548,7 @@ test_encoding(void *arg)
 /** Setup some SRVs in our SR state. If <b>also_current</b> is set, then set
  *  both current and previous SRVs.
  *  Helper of test_vote() and test_sr_compute_srv().
  * You must call sr_state_free() to free the state at the end of each test
  * function (on pass or fail). */
 static void
 test_sr_setup_srv(int also_current)
@@ -1299,7 +1299,7 @@ test_utils_auth(void *arg)
 #endif
 
  done:
-  sr_state_free();
+  sr_state_free_all();
 }
 
 static void
@@ -548,7 +548,7 @@ test_encoding(void *arg)
  *  both current and previous SRVs.
  *  Helper of test_vote() and test_sr_compute_srv().
- * You must call sr_state_free() to free the state at the end of each test
+ * You must call sr_state_free_all() to free the state at the end of each test
  * function (on pass or fail). */
 static void





More information about the tor-commits mailing list